An R6 Class to represent a PLNfit in a standard, general framework, with spherical residual covariance
Source:R/PLNfit-class.R
PLNfit_spherical.RdAn R6 Class to represent a PLNfit in a standard, general framework, with spherical residual covariance
Super class
PLNfit -> PLNfit_spherical
Active bindings
nb_paramnumber of parameters in the current PLN model
vcov_modelcharacter: the model used for the residual covariance
Methods
PLNfit_spherical$new()
Initialize a PLNfit model
Usage
PLNfit_spherical$new(responses, covariates, offsets, weights, formula, control)Arguments
responsesthe matrix of responses (called Y in the model). Will usually be extracted from the corresponding field in PLNfamily-class
covariatesdesign matrix (called X in the model). Will usually be extracted from the corresponding field in PLNfamily-class
offsetsoffset matrix (called O in the model). Will usually be extracted from the corresponding field in PLNfamily-class
weightsan optional vector of observation weights to be used in the fitting process.
formulamodel formula used for fitting, extracted from the formula in the upper-level call
controla list for controlling the optimization. See details.
Examples
if (FALSE) { # \dontrun{
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPLN <- PLN(Abundance ~ 1, data = trichoptera)
class(myPLN)
print(myPLN)
} # }