Skip to contents

Perform sparse inverse covariance estimation for the Zero Inflated Poisson lognormal model using a variational algorithm. Iterate over a range of logarithmically spaced sparsity parameter values. Use the (g)lm syntax to specify the model (including covariates and offsets).

Usage

PLNnetwork(
  formula,
  data,
  subset,
  weights,
  penalties = NULL,
  control = PLNnetwork_param()
)

Arguments

formula

an object of class "formula": a symbolic description of the model to be fitted.

data

an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which the model is called.

subset

an optional vector specifying a subset of observations to be used in the fitting process.

weights

an optional vector of observation weights to be used in the fitting process.

penalties

an optional vector of positive real number controlling the level of sparsity of the underlying network. if NULL (the default), will be set internally. See PLNnetwork_param() for additional tuning of the penalty.

control

a list-like structure for controlling the optimization, with default generated by PLNnetwork_param(). See the corresponding documentation for details;

Value

an R6 object with class PLNnetworkfamily, which contains a collection of models with class PLNnetworkfit

See also

The classes PLNnetworkfamily and PLNnetworkfit, and the and the configuration function PLNnetwork_param().

Examples

data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
fits <- PLNnetwork(Abundance ~ 1, data = trichoptera)
#> 
#>  Initialization...
#>  Adjusting 30 PLN with sparse inverse covariance estimation
#> 	Joint optimization alternating gradient descent and graphical-lasso
#> 	sparsifying penalty = 4.479926 
	sparsifying penalty = 4.137977 
	sparsifying penalty = 3.822129 
	sparsifying penalty = 3.530389 
	sparsifying penalty = 3.260917 
	sparsifying penalty = 3.012014 
	sparsifying penalty = 2.78211 
	sparsifying penalty = 2.569754 
	sparsifying penalty = 2.373607 
	sparsifying penalty = 2.192431 
	sparsifying penalty = 2.025085 
	sparsifying penalty = 1.870512 
	sparsifying penalty = 1.727737 
	sparsifying penalty = 1.595861 
	sparsifying penalty = 1.47405 
	sparsifying penalty = 1.361537 
	sparsifying penalty = 1.257612 
	sparsifying penalty = 1.16162 
	sparsifying penalty = 1.072954 
	sparsifying penalty = 0.9910565 
	sparsifying penalty = 0.91541 
	sparsifying penalty = 0.8455375 
	sparsifying penalty = 0.7809984 
	sparsifying penalty = 0.7213854 
	sparsifying penalty = 0.6663227 
	sparsifying penalty = 0.6154629 
	sparsifying penalty = 0.5684851 
	sparsifying penalty = 0.5250931 
	sparsifying penalty = 0.4850132 
	sparsifying penalty = 0.4479926 

#>  Post-treatments
#>  DONE!