Skip to contents

This data set gives the abundance of 32 mollusk species in 163 samples. For each sample, 4 additional covariates are known.

Usage

mollusk

Format

A list with 2 two data frames:

Abundance

a 163 x 32 data frame of abundancies/counts (163 samples and 32 mollusk species)

Covariate

a 163 x 4 data frame of covariates:

site

a factor with 8 levels indicating the sampling site

season

a factor with 4 levels indicating the season

method

a factor with 2 levels for the method of sampling - wood or string

duration

a numeric with 3 levels for the time of exposure in week

In order to prepare the data for using formula in multivariate analysis (multiple outputs and inputs), use prepare_data(). Original data set has been extracted from ade4.

Data from Richardot-Coulet, Chessel and Bournaud.

References

Richardot-Coulet, M., Chessel D. and Bournaud M. (1986) Typological value of the benthos of old beds of a large river. Methodological approach. Archiv fùr Hydrobiologie, 107, 363–383.

See also

Examples

data(mollusk)
mollusc <- prepare_data(mollusk$Abundance, mollusk$Covariate)
#> Warning: ! There is at least one empty sample in `counts`.
#> ℹ <4> samples (<134/137/145/146>) in `counts` have been dropped for lack of
#>   positive counts.
#> ! 3 species are absent from all the samples of a level of a factor covariate,
#>   while present elsewhere beyond what chance would explain (site: 3).
#> ℹ A model without this covariate fits these structural zeros by sending latent
#>   means to minus infinity, which distorts the variances and, in a network, the
#>   edges of these species.
#> ℹ See `structural_zeros()` for the list.