PLNLDA: Poisson lognormal model towards Linear Discriminant Analysis
Description
Fit the Poisson lognormal for LDA with a variational algorithm. Use the (g)lm syntax for model specification (covariates, offsets).
Usage
PLNLDA(formula, data, subset, weights, grouping, control = PLNLDA_param())
Value
an R6 object with class PLNLDAfit()
Arguments
formula
an object of class "formula": a symbolic description of the model to be fitted.
data
an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. If not found in data, the variables are taken from environment(formula), typically the environment from which the model is called.
subset
an optional vector specifying a subset of observations to be used in the fitting process.
weights
an optional vector of observation weights to be used in the fitting process.
grouping
a factor specifying the class of each observation used for discriminant analysis.
control
a list-like structure for controlling the optimization, with default generated by PLNLDA_param(). See the associated documentation.
Details
See PLNLDA_param() for a full description of the optimization parameters.
Note that unlike PLN_param(), PLNLDA_param() does not expose the "fixed" covariance option or the Omega parameter, which are not meaningful in the LDA context.