| PLNPCAfamily | R Documentation |
The function PLNPCA() produces an instance of this class.
This class comes with a set of methods, some of them being useful for the user:
See the documentation for getBestModel(),
getModel() and plot().
PLNfamily -> PLNPCAfamily
ranksthe dimensions of the successively fitted models
PLNPCAfamily$new()Initialize all models in the collection.
A single SVD of the residual matrix M - X*B is computed once and shared across
all ranks. M and B come from either a user-provided PLNfit inception or a
fast LM on log-transformed counts (default, controlled by init_method).
PLNPCAfamily$new( ranks, responses, covariates, offsets, weights, formula, control )
ranksthe dimensions of the successively fitted models
responsesthe matrix of responses common to every models
covariatesthe matrix of covariates common to every models
offsetsthe matrix of offsets common to every models
weightsthe vector of observation weights
formulamodel formula used for fitting, extracted from the formula in the upper-level call
controllist controlling the optimization and the model
PLNPCAfamily$optimize()Call to the C++ optimizer on all models of the collection
PLNPCAfamily$optimize(config)
configlist controlling the optimization.
PLNPCAfamily$getModel()Extract model from collection and add "PCA" class for compatibility with factoextra::fviz()
PLNPCAfamily$getModel(var, index = NULL)
varvalue of the parameter (rank for PLNPCA, sparsity for PLNnetwork) that identifies the model to be extracted from the collection. If no exact match is found, the model with closest parameter value is returned with a warning.
indexInteger index of the model to be returned. Only the first value is taken into account.
a PLNPCAfit object
PLNPCAfamily$getBestModel()Extract best model in the collection
PLNPCAfamily$getBestModel(crit = c("ICL", "BIC"))
crita character for the criterion used to performed the selection. Either
"ICL", "BIC". Default is ICL
a PLNPCAfit object
PLNPCAfamily$plot()Lineplot of selected criteria for all models in the collection
PLNPCAfamily$plot(criteria = c("loglik", "BIC", "ICL"), reverse = FALSE)
criteriaA valid model selection criteria for the collection of models. Any of "loglik", "BIC" or "ICL" (all).
reverseA logical indicating whether to plot the value of the criteria in the "natural" direction (loglik - penalty) or in the "reverse" direction (-2 loglik + penalty). Default to FALSE, i.e use the natural direction, on the same scale as the log-likelihood.
A ggplot2::ggplot object
PLNPCAfamily$show()User friendly print method
PLNPCAfamily$show()
PLNPCAfamily$clone()The objects of this class are cloneable with this method.
PLNPCAfamily$clone(deep = FALSE)
deepWhether to make a deep clone.
The function PLNPCA(), the class PLNPCAfit()
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPCAs <- PLNPCA(Abundance ~ 1 + offset(log(Offset)), data = trichoptera, ranks = 1:5)
class(myPCAs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.