| PLNfit_fixedcov | R Documentation |
An R6 Class to represent a PLNfit in a standard, general framework, with fixed (inverse) residual covariance
PLNfit -> PLNfit_fixedcov
nb_paramnumber of parameters in the current PLN model
vcov_modelcharacter: the model used for the residual covariance
vcov_coefmatrix of sandwich estimator of the variance-covariance of B (needs known covariance at the moment)
PLNfit_fixedcov$new()Initialize a PLNfit model
PLNfit_fixedcov$new(responses, covariates, offsets, weights, formula, control)
responsesthe matrix of responses (called Y in the model). Will usually be extracted from the corresponding field in PLNfamily-class
covariatesdesign matrix (called X in the model). Will usually be extracted from the corresponding field in PLNfamily-class
offsetsoffset matrix (called O in the model). Will usually be extracted from the corresponding field in PLNfamily-class
weightsan optional vector of observation weights to be used in the fitting process.
formulamodel formula used for fitting, extracted from the formula in the upper-level call
controla list for controlling the optimization. See details.
PLNfit_fixedcov$optimize()Call to the NLopt or TORCH optimizer and update of the relevant fields
PLNfit_fixedcov$optimize(responses, covariates, offsets, weights, config)
responsesthe matrix of responses (called Y in the model). Will usually be extracted from the corresponding field in PLNfamily-class
covariatesdesign matrix (called X in the model). Will usually be extracted from the corresponding field in PLNfamily-class
offsetsoffset matrix (called O in the model). Will usually be extracted from the corresponding field in PLNfamily-class
weightsan optional vector of observation weights to be used in the fitting process.
configpart of the control argument which configures the optimizer
PLNfit_fixedcov$clone()The objects of this class are cloneable with this method.
PLNfit_fixedcov$clone(deep = FALSE)
deepWhether to make a deep clone.
## Not run:
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPLN <- PLN(Abundance ~ 1, data = trichoptera)
class(myPLN)
print(myPLN)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.