| PLNfit_genpop | R Documentation |
Sigma = sigma2 * (rho * C + (1 - rho) * I_p), where C is a fixed p x p
correlation matrix supplied by the user (control$C) and (sigma2, rho) are estimated.
See GeneticCovTraits in src/covariance_pln.h for the C++ side.
PLNfit -> PLNfit_genpop
nb_paramnumber of parameters in the current PLN model
vcov_modelcharacter: the model used for the residual covariance
gen_para list with the two extra parameters of the genpop covariance model: sigma2 (variance scale) and rho (mixing weight / heritability), decoded from Sigma and C.
PLNfit_genpop$new()Initialize a PLNfit_genpop model
PLNfit_genpop$new(responses, covariates, offsets, weights, formula, control)
responsesthe matrix of responses (called Y in the model). Will usually be extracted from the corresponding field in PLNfamily-class
covariatesdesign matrix (called X in the model). Will usually be extracted from the corresponding field in PLNfamily-class
offsetsoffset matrix (called O in the model). Will usually be extracted from the corresponding field in PLNfamily-class
weightsan optional vector of observation weights to be used in the fitting process.
formulamodel formula used for fitting, extracted from the formula in the upper-level call
controla list for controlling the optimization, must include a field C (the fixed p x p correlation matrix). See details.
PLNfit_genpop$optimize()Call to the NLopt or builtin optimizer and update of the relevant fields
PLNfit_genpop$optimize(responses, covariates, offsets, weights, config)
responsesthe matrix of responses (called Y in the model). Will usually be extracted from the corresponding field in PLNfamily-class
covariatesdesign matrix (called X in the model). Will usually be extracted from the corresponding field in PLNfamily-class
offsetsoffset matrix (called O in the model). Will usually be extracted from the corresponding field in PLNfamily-class
weightsan optional vector of observation weights to be used in the fitting process.
configpart of the control argument which configures the optimizer
PLNfit_genpop$clone()The objects of this class are cloneable with this method.
PLNfit_genpop$clone(deep = FALSE)
deepWhether to make a deep clone.
## Not run:
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
p <- ncol(trichoptera$Abundance)
C <- 0.5^abs(outer(1:p, 1:p, "-")); diag(C) <- 1
myPLN <- PLN(Abundance ~ 1, data = trichoptera, control = PLN_param(covariance = "genpop", C = C))
class(myPLN)
print(myPLN)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.