powered by
An R6 Class to represent a PLNfit in a standard, general framework, with spherical residual covariance
PLNfit -> PLNfit_spherical
PLNfit
PLNfit_spherical
nb_param
number of parameters in the current PLN model
vcov_model
character: the model used for the residual covariance
PLNfit_spherical$new()
PLNfit_spherical$clone()
Inherited methods PLNfit$optimize() PLNfit$optimize_vestep() PLNfit$postTreatment() PLNfit$predict() PLNfit$predict_cond() PLNfit$print() PLNfit$show() PLNfit$update()
PLNfit$optimize()
PLNfit$optimize_vestep()
PLNfit$postTreatment()
PLNfit$predict()
PLNfit$predict_cond()
PLNfit$print()
PLNfit$show()
PLNfit$update()
Initialize a PLNfit model
PLNfit_spherical$new(responses, covariates, offsets, weights, formula, control)
responses
the matrix of responses (called Y in the model). Will usually be extracted from the corresponding field in PLNfamily-class
covariates
design matrix (called X in the model). Will usually be extracted from the corresponding field in PLNfamily-class
offsets
offset matrix (called O in the model). Will usually be extracted from the corresponding field in PLNfamily-class
weights
an optional vector of observation weights to be used in the fitting process.
formula
model formula used for fitting, extracted from the formula in the upper-level call
control
a list for controlling the optimization. See details.
The objects of this class are cloneable with this method.
PLNfit_spherical$clone(deep = FALSE)
deep
Whether to make a deep clone.
if (FALSE) { data(trichoptera) trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate) myPLN <- PLN(Abundance ~ 1, data = trichoptera) class(myPLN) print(myPLN) }
Run the code above in your browser using DataLab