An R6 Class to represent a collection of PLNmixturefit
Source:R/PLNmixturefamily-class.R
PLNmixturefamily.RdThe function PLNmixture() produces an instance of this class.
This class comes with a set of methods, some of them being useful for the user:
See the documentation for getBestModel(), getModel() and plot().
See also
The function PLNmixture, the class PLNmixturefit
Super class
PLNfamily -> PLNmixturefamily
Active bindings
clustersvector indicating the number of clusters considered is the successively fitted models
Methods
Inherited methods
PLNmixturefamily$new()
helper function for forward smoothing: split a group
Initialize all models in the collection.
Usage
PLNmixturefamily$new(
clusters,
responses,
covariates,
offsets,
formula,
control
)Arguments
clustersthe dimensions of the successively fitted models
responsesthe matrix of responses common to every models
covariatesthe matrix of covariates common to every models
offsetsthe matrix of offsets common to every models
formulamodel formula used for fitting, extracted from the formula in the upper-level call
controla list for controlling the optimization. See details.
controla list for controlling the optimization. See details.
PLNmixturefamily$smooth()
function to restart clustering to avoid local minima by smoothing the loglikelihood values as a function of the number of clusters
PLNmixturefamily$plot()
Lineplot of selected criteria for all models in the collection
Usage
PLNmixturefamily$plot(criteria = c("loglik", "BIC", "ICL"), reverse = FALSE)Arguments
criteriaA valid model selection criteria for the collection of models. Any of "loglik", "BIC" or "ICL" (all).
reverseA logical indicating whether to plot the value of the criteria in the "natural" direction (loglik - 0.5 penalty) or in the "reverse" direction (-2 loglik + penalty). Default to FALSE, i.e use the natural direction, on the same scale as the log-likelihood..
Returns
A ggplot2::ggplot object
PLNmixturefamily$plot_objective()
Plot objective value of the optimization problem along the penalty path
Returns
a ggplot2::ggplot graph
PLNmixturefamily$getBestModel()
Extract best model in the collection
Usage
PLNmixturefamily$getBestModel(crit = c("BIC", "ICL", "loglik"))Arguments
crita character for the criterion used to performed the selection. Either "BIC", "ICL" or "loglik". Default is
ICL
Returns
a PLNmixturefit object