The Poisson-lognormal model and variants (Chiquet, Mariadassou and Robin, 2021 tools:::Rd_expr_doi("10.3389/fevo.2021.588292")) can be used for a variety of multivariate problems when count data are at play, including principal component analysis for count data, discriminant analysis, model-based clustering and network inference. Implements variational algorithms to fit such models accompanied with a set of functions for visualization and diagnostic.
Maintainer: Julien Chiquet [email protected] (ORCID)
Authors:
Julien Chiquet [email protected] (ORCID)
Mahendra Mariadassou [email protected] (ORCID)
Stéphane Robin [email protected]
Other contributors:
François Gindraud [email protected] [contributor]
Julie Aubert [email protected] [contributor]
Bastien Batardière [email protected] [contributor]
Giovanni Poggiato [email protected] [contributor]
Cole Trapnell [email protected] [contributor]
Maddy Duran [email protected] [contributor]
Ryan Friedman [email protected] [contributor]
Useful links: