The function PLNnetwork() produces an instance of this class.

This class comes with a set of methods mostly used to compare network fits (in terms of goodness of fit) or extract one from the family (based on penalty parameter and/or goodness of it). See the documentation for getBestModel(), getModel() and plot() for the user-facing ones.

See also

The function PLNnetwork(), the class PLNnetworkfit

Super classes

PLNmodels::PLNfamily -> PLNmodels::Networkfamily -> PLNnetworkfamily

Methods

Inherited methods


Method new()

Initialize all models in the collection

Usage

PLNnetworkfamily$new(penalties, data, control)

Arguments

penalties

a vector of positive real number controlling the level of sparsity of the underlying network.

data

a named list used internally to carry the data matrices

control

a list for controlling the optimization.

Returns

Update current PLNnetworkfit with smart starting values


Method stability_selection()

Compute the stability path by stability selection

Usage

PLNnetworkfamily$stability_selection(
  subsamples = NULL,
  control = PLNnetwork_param()
)

Arguments

subsamples

a list of vectors describing the subsamples. The number of vectors (or list length) determines the number of subsamples used in the stability selection. Automatically set to 20 subsamples with size 10*sqrt(n) if n >= 144 and 0.8*n otherwise following Liu et al. (2010) recommendations.

control

a list controlling the main optimization process in each call to PLNnetwork(). See PLNnetwork() and PLN_param() for details.


Method clone()

The objects of this class are cloneable with this method.

Usage

PLNnetworkfamily$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
fits <- PLNnetwork(Abundance ~ 1, data = trichoptera)
#> 
#>  Initialization...
#>  Adjusting 30 PLN with sparse inverse covariance estimation
#> 	Joint optimization alternating gradient descent and graphical-lasso
#> 	sparsifying penalty = 7.353689 
	sparsifying penalty = 6.792388 
	sparsifying penalty = 6.273931 
	sparsifying penalty = 5.795047 
	sparsifying penalty = 5.352716 
	sparsifying penalty = 4.944148 
	sparsifying penalty = 4.566765 
	sparsifying penalty = 4.218188 
	sparsifying penalty = 3.896217 
	sparsifying penalty = 3.598823 
	sparsifying penalty = 3.324127 
	sparsifying penalty = 3.0704 
	sparsifying penalty = 2.836039 
	sparsifying penalty = 2.619566 
	sparsifying penalty = 2.419617 
	sparsifying penalty = 2.23493 
	sparsifying penalty = 2.064339 
	sparsifying penalty = 1.90677 
	sparsifying penalty = 1.761228 
	sparsifying penalty = 1.626795 
	sparsifying penalty = 1.502623 
	sparsifying penalty = 1.387929 
	sparsifying penalty = 1.28199 
	sparsifying penalty = 1.184137 
	sparsifying penalty = 1.093752 
	sparsifying penalty = 1.010267 
	sparsifying penalty = 0.9331545 
	sparsifying penalty = 0.8619276 
	sparsifying penalty = 0.7961374 
	sparsifying penalty = 0.7353689 

#>  Post-treatments
#>  DONE!
class(fits)
#> [1] "PLNnetworkfamily" "Networkfamily"    "PLNfamily"        "R6"