An R6 Class to represent a ZIPLNfit in a standard, general framework, with diagonal residual covariance
Source:R/ZIPLNfit-class.R
ZIPLNfit_diagonal.RdAn R6 Class to represent a ZIPLNfit in a standard, general framework, with diagonal residual covariance
Super class
ZIPLNfit -> ZIPLNfit_diagonal
Active bindings
nb_param_plnnumber of parameters in the PLN part of the current model
vcov_modelcharacter: the model used for the residual covariance
Methods
ZIPLNfit_diagonal$new()
Initialize a ZIPLNfit_diagonal model
Usage
ZIPLNfit_diagonal$new(data, control)Examples
if (FALSE) { # \dontrun{
# See other examples in function ZIPLN
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPLN <- ZIPLN(Abundance ~ 1, data = trichoptera, control = ZIPLN_param(covariance = "diagonal"))
class(myPLN)
print(myPLN)
} # }