An R6 Class to represent a ZIPLNfit in a standard, general framework, with sparse inverse residual covariance
Source:R/ZIPLNfit-class.R
ZIPLNfit_sparse.RdAn R6 Class to represent a ZIPLNfit in a standard, general framework, with sparse inverse residual covariance
Super class
ZIPLNfit -> ZIPLNfit_sparse
Active bindings
penaltythe global level of sparsity in the current model
penalty_weightsa matrix of weights controlling the amount of penalty element-wise.
n_edgesnumber of edges if the network (non null coefficient of the sparse precision matrix)
nb_param_plnnumber of parameters in the PLN part of the current model
vcov_modelcharacter: the model used for the residual covariance
pen_loglikvariational lower bound of the l1-penalized loglikelihood
ebic_gammathe tuning parameter gamma of the EBIC, between 0 and 1. Zero gives back the BIC; the default 0.5 is the value recommended by Foygel and Drton (2010). Assign to it to change the EBIC of this fit.
EBICvariational lower bound of the EBIC of Foygel and Drton (2010), that is the BIC with the additional penalty 2 gamma |E| log(p) on the edge set
densityproportion of non-null edges in the network
criteriaa vector with loglik, penalized loglik, BIC, EBIC, ICL, R_squared, number of parameters, number of edges and graph density
Methods
ZIPLNfit_sparse$optimize()
Call to the optimizer and update of the relevant fields.
Reports non-convergence of the graphical Lasso on top of ZIPLNfit's method.
ZIPLNfit_sparse$latent_network()
Extract interaction network in the latent space
Usage
ZIPLNfit_sparse$latent_network(type = c("partial_cor", "support", "precision"))ZIPLNfit_sparse$plot_network()
plot the latent network.
Arguments
typeedge value in the network. Either "precision" (coefficient of the precision matrix) or "partial_cor" (partial correlation between species).
outputOutput type. Either
igraph(for the network) orcorrplot(for the adjacency matrix)edge.colorLength 2 color vector. Color for positive/negative edges. Default is
c("#F8766D", "#00BFC4"). Only relevant for igraph output.remove.isolatedif
TRUE, isolated node are remove before plotting. Only relevant for igraph output.node.labelsvector of character. The labels of the nodes. The default will use the column names ot the response matrix.
layoutan optional igraph layout. Only relevant for igraph output.
edge.alphaopacity of the weakest edge, the strongest one being fully opaque, so that the strength of an edge can be read off a dense network. Default is
0.2. Set it to1for uniformly opaque edges. Only relevant for igraph output withtype = "partial_cor".plotlogical. Should the final network be displayed or only sent back to the user. Default is
TRUE.
Examples
if (FALSE) { # \dontrun{
# See other examples in function ZIPLN
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPLN <- ZIPLN(Abundance ~ 1, data = trichoptera, control= ZIPLN_param(penalty = 1))
class(myPLN)
print(myPLN)
plot(myPLN)
} # }