R/PLNnetworkfamily-S3methods.R
coefficient_path.RdExtract the regularization path of a PLNnetwork fit
coefficient_path(Robject, precision = TRUE, corr = TRUE)an object with class Networkfamily, i.e. an output from PLNnetwork()
a logical, should the coefficients of the precision matrix Omega or the covariance matrix Sigma be sent back. Default is TRUE.
a logical, should the correlation (partial in case precision = TRUE) be sent back. Default is TRUE.
Sends back a tibble/data.frame.
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
fits <- PLNnetwork(Abundance ~ 1, data = trichoptera)
#>
#> Initialization...
#> Adjusting 30 PLN with sparse inverse covariance estimation
#> Joint optimization alternating gradient descent and graphical-lasso
#> sparsifying penalty = 7.353689
sparsifying penalty = 6.792388
sparsifying penalty = 6.273931
sparsifying penalty = 5.795047
sparsifying penalty = 5.352716
sparsifying penalty = 4.944148
sparsifying penalty = 4.566765
sparsifying penalty = 4.218188
sparsifying penalty = 3.896217
sparsifying penalty = 3.598823
sparsifying penalty = 3.324127
sparsifying penalty = 3.0704
sparsifying penalty = 2.836039
sparsifying penalty = 2.619566
sparsifying penalty = 2.419617
sparsifying penalty = 2.23493
sparsifying penalty = 2.064339
sparsifying penalty = 1.90677
sparsifying penalty = 1.761228
sparsifying penalty = 1.626795
sparsifying penalty = 1.502623
sparsifying penalty = 1.387929
sparsifying penalty = 1.28199
sparsifying penalty = 1.184137
sparsifying penalty = 1.093752
sparsifying penalty = 1.010267
sparsifying penalty = 0.9331545
sparsifying penalty = 0.8619276
sparsifying penalty = 0.7961374
sparsifying penalty = 0.7353689
#> Post-treatments
#> DONE!
head(coefficient_path(fits))
#> Node1 Node2 Coeff Penalty Edge
#> 1 Aga Che 0 7.353689 Aga|Che
#> 2 Ath Che 0 7.353689 Ath|Che
#> 3 Cea Che 0 7.353689 Cea|Che
#> 4 Ced Che 0 7.353689 Ced|Che
#> 5 All Che 0 7.353689 All|Che
#> 6 Che Hyc 0 7.353689 Che|Hyc