LDA visualization (individual and/or variable factor map(s)) for a PLNPCAfit object
Source: R/PLNLDAfit-S3methods.R
plot.PLNLDAfit.RdLDA visualization (individual and/or variable factor map(s)) for a PLNPCAfit object
Arguments
- x
an R6 object with class PLNPCAfit
- map
the type of output for the PCA visualization: either "individual", "variable" or "both". Default is "both".
- nb_axes
scalar: the number of axes to be considered when map = "both". The default is min(3,rank).
- axes
numeric, the axes to use for the plot when map = "individual" or "variable". Default it c(1,min(rank))
- var_cols
a character or factor to define the color associated with the variables. By default, all variables receive the default color of the current palette.
- plot
logical. Should the plot be displayed or sent back as
ggplot2::ggplotobject- main
character. A title for the single plot (individual or variable factor map). If NULL (the default), an hopefully appropriate title will be used.
- ...
Not used (S3 compatibility).
Value
displays an individual and/or variable factor maps for the corresponding axes, and/or sends back a ggplot2::ggplot or gtable object
Examples
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPLNLDA <- PLNLDA(Abundance ~ 1, grouping = Group, data = trichoptera)
#>
#> Performing discriminant Analysis...
#> DONE!
if (FALSE) { # \dontrun{
plot(myPLNLDA, map = "individual", nb_axes = 2)
} # }