R/PLNPCAfit-S3methods.R, R/PLNfit-S3methods.R, R/PLNmixturefit-S3methods.R, and 1 more
standard_error.RdExtracts univariate standard errors for the estimated coefficient of B. Standard errors are computed from the (approximate) Fisher information matrix.
# S3 method for class 'PLNPCAfit'
standard_error(
object,
type = c("variational", "jackknife", "sandwich"),
parameter = c("B", "Omega")
)
standard_error(
object,
type = c("sandwich", "variational", "jackknife"),
parameter = c("B", "Omega")
)
# S3 method for class 'PLNfit'
standard_error(
object,
type = c("sandwich", "variational", "jackknife", "bootstrap"),
parameter = c("B", "Omega")
)
# S3 method for class 'PLNfit_fixedcov'
standard_error(
object,
type = c("sandwich", "variational", "jackknife", "bootstrap"),
parameter = c("B", "Omega")
)
# S3 method for class 'PLNmixturefit'
standard_error(
object,
type = c("variational", "jackknife", "sandwich"),
parameter = c("B", "Omega")
)
# S3 method for class 'PLNnetworkfit'
standard_error(
object,
type = c("variational", "jackknife", "sandwich"),
parameter = c("B", "Omega")
)A p * d positive matrix (same size as \(B\)) with standard errors for the coefficients of \(B\)
standard_error(PLNPCAfit): Component-wise standard errors of B in PLNPCAfit (not implemented yet)
standard_error(PLNfit): Component-wise standard errors of B in PLNfit
standard_error(PLNfit_fixedcov): Component-wise standard errors of B in PLNfit_fixedcov
standard_error(PLNmixturefit): Component-wise standard errors of B in PLNmixturefit (not implemented yet)
standard_error(PLNnetworkfit): Component-wise standard errors of B in PLNnetworkfit (not implemented yet)
vcov.PLNfit() for the complete variance covariance estimation of the coefficient
data(trichoptera)
trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
myPLN <- PLN(Abundance ~ 1 + offset(log(Offset)), data = trichoptera,
control = PLN_param(config_post = list(sandwich_var = TRUE)))
#>
#> Initialization...
#> Adjusting a full covariance PLN model with nlopt optimizer
#> Post-treatments...
#> DONE!
standard_error(myPLN)
#> Che Hyc Hym Hys Psy Aga
#> (Intercept) 0.6879427 0.5945803 0.1893622 0.4861577 0.04810579 0.2091294
#> Glo Ath Cea Ced Set All
#> (Intercept) 0.3438246 0.3437573 0.2473409 0.188578 0.2571046 0.2816838
#> Han Hfo Hsp Hve Sta
#> (Intercept) 0.3759095 0.3868234 0.302045 0.4049505 0.1778581